/*
 * GNOME time/date display module.
 * (C) 1997 The Free Software Foundation
 *
 * Authors: Miguel de Icaza
 *          Federico Mena
 *
 * Feel free to implement new look and feels :-)
 */

#ifndef _CLOCK_H_
#define _CLOCK_H_

BEGIN_GNOME_DECLS

GtkWidget * make_clock_applet(const gchar *goad_id);

END_GNOME_DECLS

#endif
